
TODO: TODO_18_51_46_14: refactor FS_42_76_93_51 zero_arg_interp into FS_15_79_76_85 line processor

Factor out abstract `LineProcessor` with their individual implementations.

And the first individual implementation should be FS_55_57_45_04 enum selector.

Plugin `FirstArgInterpFactory` should (probably) be selecting line processors instead of interps.
In this case `InterpTreeInterpFactory.default` instance is the line processor.
